package com.xinelu.manage.mapper.poserInfo;

import com.xinelu.common.core.domain.entity.SysDictData;
import com.xinelu.manage.domain.poserInfo.PoserInfo;
import com.xinelu.manage.dto.poserInfo.PoserInfoDTO;
import com.xinelu.manage.vo.poserInfo.PoserInfoVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 泉医到家系统海报模块信息（包含咨询简介信息）Mapper接口
 *
 * @author xinyilu
 * @date 2023-02-10
 */
public interface PoserInfoMapper {
    /**
     * 查询泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param id 泉医到家系统海报模块信息（包含咨询简介信息）主键
     * @return 泉医到家系统海报模块信息（包含咨询简介信息）
     */
    PoserInfoVO selectPoserInfoById(Long id);

    /**
     * 查询泉医到家系统海报模块信息（包含咨询简介信息）列表
     *
     * @param poserInfo 泉医到家系统海报模块信息（包含咨询简介信息）
     * @return 泉医到家系统海报模块信息（包含咨询简介信息）集合
     */
    List<PoserInfoVO> selectPoserInfoList(PoserInfoVO poserInfo);

    /**
     * 查询泉医到家系统海报模块信息（包含咨询简介信息）列表
     *
     * @param poserInfo 泉医到家系统海报模块信息（包含咨询简介信息）
     * @return 泉医到家系统海报模块信息（包含咨询简介信息）集合
     */
    List<PoserInfoVO> getPoserInfoList(PoserInfoVO poserInfo);

    /**
     * 新增泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param poserInfo 泉医到家系统海报模块信息（包含咨询简介信息）
     * @return 结果
     */
    int insertPoserInfo(PoserInfoDTO poserInfo);

    /**
     * 修改泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param poserInfo 泉医到家系统海报模块信息（包含咨询简介信息）
     * @return 结果
     */
    int updatePoserInfo(PoserInfoDTO poserInfo);

    /**
     * 删除泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param id 泉医到家系统海报模块信息（包含咨询简介信息）主键
     * @return 结果
     */
    int deletePoserInfoById(Long id);

    /**
     * 批量删除泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deletePoserInfoByIds(Long[] ids);

    /**
     * 根据moduleType批量删除泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param moduleType 需要删除的数据主键集合
     * @return 结果
     */
    int deletePoserInfoByModuleType(String[] moduleType);


    /**
     * 新增订单评价图片信息
     *
     * @param poserInfoDTO 订单评价图片信息
     * @return 结果
     */
    int insertPoserInfoList(List<PoserInfoDTO> poserInfoDTO);

    /**
     * 查询泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param poserInfo 泉医到家系统海报模块信息（包含咨询简介信息）主键
     * @return 泉医到家系统海报模块信息（包含咨询简介信息）
     */
    PoserInfoVO selectPoserInfoByModuleType(PoserInfoVO poserInfo);

    /**
     * 查询泉医到家系统海报模块信息（包含咨询简介信息）
     *
     * @param poserInfo 泉医到家系统海报模块信息（包含咨询简介信息）主键
     * @return 泉医到家系统海报模块信息（包含咨询简介信息）
     */
    List<PoserInfoVO> selectPoserInfoByModuleTypeList(PoserInfoVO poserInfo);

    /**
     * 查询当前海报模块是否存在
     *
     * @param moduleType 模块类型
     * @param stationId  护理站id
     * @param itemId     护理项目id
     * @return 数量
     */
    int getPoserInfoByModuleTypeAndId(@Param("moduleType") String moduleType, @Param("stationId") Long stationId, @Param("itemId") Long itemId);

    /**
     * 小程序根据模块类型查询海报
     *
     * @param moduleTyp 模块类型
     * @return List<PoserInfo>
     */
    List<PoserInfo> selectPoserListByModuleTyp(String moduleTyp);


    /**
     * 从字典表中查询海报跳转链接
     *
     * @param dictType 类型
     * @return java.util.List<com.xinyilu.common.core.domain.entity.SysDictData>
     **/
    List<SysDictData> selectPosterImageJump(String dictType);
}
